@@ -18,8 +18,9 @@ if __name__ == '__main__':
     parser_init.add_argument('--base-dir', help='Base directory', type=str)
     parser_init.add_argument('--api-title', help='API title', type=str)
     parser_init.add_argument('--api-description', help='API description', type=str)
-    parser_init.add_argument('--gcp-project', help='Google cloud project id', type=str)
-    parser_init.add_argument('--gcp-region', help='Google cloud region', type=str)
+    parser_init.add_argument('--cloud', help='Cloud type', type=str, default='gcp')
+    parser_init.add_argument('--project', help='Cloud project id', type=str)
+    parser_init.add_argument('--region', help='Cloud region', type=str)
     parser_init.set_defaults(which='init')
 
     parser_endpoint = subparsers.add_parser('endpoints', help='endpoints')
