@@ -13,7 +13,7 @@ class Runtime:
         self.config = config
         self.operation_id = operation_id
         self.entry_point = kwargs.get('entry_point', 'main')
-        self.runtime = kwargs.get('runtime', 'python310')
+        self.runtime = kwargs.get('runtime', 'python311')
         self.memory = kwargs.get('memory', '128MB')
         self.dependencies = kwargs.get('dependencies', [])
         self.trigger = kwargs.get('trigger', 'http')
@@ -111,8 +111,26 @@ def cli_main(args, config: Config) -> int:
         )
         return 1
     if args.action == 'init':
-        init_file_structure(config)
-        print(helpers.bcolors.OKGREEN + 'Init API-Gateway success' + helpers.bcolors.ENDC)
+        manager = steps.Manager(config, [
+            steps.StepFunction(
+                'init-file-structure',
+                lambda x: init_file_structure(config)
+            ),
+            steps.StepCommand(
+                shlex.split(
+                    f'gcloud services enable cloudfunctions.googleapis.com --project="{config.project}"'
+                )
+            ),
+            steps.StepCommand(
+                shlex.split(
+                    f'gcloud services enable cloudbuild.googleapis.com --project="{config.project}"'
+                )
+            ),
+        ], simulate=args.simulate)
+        rc = manager.run()
+        if rc != 0:
+            return rc
+        print(helpers.bcolors.OKGREEN + 'Init API-Endpoint success' + helpers.bcolors.ENDC)
         return 0
     elif args.action == 'list':
         endpoints = endpoint_list(config)
