@@ -19,7 +19,7 @@ class Runtime:
 
     @property
     def command_build(self) -> str:
-        return f"gcloud builds submit --pack image=gcr.io/{self.config.gcp_project}/{self.operation_id} --project={self.config.gcp_project}"
+        return f"gcloud builds submit --pack image=gcr.io/{self.config.project}/{self.operation_id} --project={self.config.project}"
 
     @property
     def command_create(self) -> str:
@@ -34,8 +34,8 @@ class Runtime:
 
         return " ".join([
             f"gcloud beta run jobs create {name}"
-            f" --image='gcr.io/{self.config.gcp_project}/{self.operation_id}' --tasks 1 {env}"
-            f" --max-retries 3 --region={self.config.gcp_region} --project={self.config.gcp_project}",
+            f" --image='gcr.io/{self.config.project}/{self.operation_id}' --tasks 1 {env}"
+            f" --max-retries 3 --region={self.config.region} --project={self.config.project}",
             "" if self.memory is None else f"--memory={self.memory}",
             "" if self.cpu is None else f"--cpu={self.cpu}",
         ])
@@ -43,12 +43,12 @@ class Runtime:
     @property
     def command_delete(self) -> str:
         name = self.operation_id.replace('_', '-')
-        return f"gcloud beta run jobs delete {name} --region='{self.config.gcp_region}' --project='{self.config.gcp_project}'"
+        return f"gcloud beta run jobs delete {name} --region='{self.config.region}' --project='{self.config.project}'"
 
     @property
     def command_run(self) -> str:
         name = self.operation_id.replace('_', '-')
-        return f"gcloud beta run jobs execute {name} --region='{self.config.gcp_region}' --project='{self.config.gcp_project}'"
+        return f"gcloud beta run jobs execute {name} --region='{self.config.region}' --project='{self.config.project}'"
 
     @property
     def command_run_dev(self) -> str:
@@ -63,7 +63,8 @@ class Job:
     def __init__(self, operation_id: str, **kwargs):
         self.operation_id = operation_id
 
-    def runtime(self, config: Config) -> Runtime:
+    def runtime(self, config: Config, **kwargs) -> Runtime:
+        is_debug = kwargs.get('is_debug', False)
         config_path = f'{config.base_dir}/jobs/config.yaml'
         if Path(config_path).exists():
             with open(config_path) as f:
@@ -78,7 +79,8 @@ class Job:
         else:
             env_data = None
 
-        print('ENV Data', env_data)
+        if is_debug:
+            print('ENV Data', env_data)
         return Runtime(config, self.operation_id, env=env_data, **runtime_config)
 
 
@@ -109,12 +111,12 @@ def cli_main(args, config: Config):
         manager = steps.Manager(config, [
             steps.StepCommand(
                 shlex.split(
-                    f'gcloud services enable run.googleapis.com --project="{config.gcp_project}"'
+                    f'gcloud services enable run.googleapis.com --project="{config.project}"'
                 )
             ),
             steps.StepCommand(
                 shlex.split(
-                    f'gcloud services enable cloudscheduler.googleapis.com --project="{config.gcp_project}"'
+                    f'gcloud services enable cloudscheduler.googleapis.com --project="{config.project}"'
                 )
             ),
         ], simulate=args.simulate)
@@ -196,7 +198,7 @@ def cli_main(args, config: Config):
 
         print('# Deploy')
         job = jobs[0]
-        runtime = job.runtime(config)
+        runtime = job.runtime(config, is_debug=args.debug)
         commands = [x for x in [
             # delete job if exists?
             steps.StepCommand(
@@ -211,10 +213,12 @@ def cli_main(args, config: Config):
                 shlex.split(runtime.command_delete),
                 work_dir=f'{config.base_dir}/jobs/{job_name}',
                 can_fail=True,
+                retry=3,
             ),
             steps.StepCommand(
                 shlex.split(runtime.command_create),
                 work_dir=f'{config.base_dir}/jobs/{job_name}',
+                retry=3,
             ),
         ] if x is not None]
         manager = steps.Manager(config, commands, simulate=args.simulate)
