@@ -117,6 +117,16 @@ class StepCommand(Step):
                 break
 
 
+class StepFunction(Step):
+    def __init__(self, name: str, function):
+        self.name = name
+        self.function = function
+
+    def run(self, config: Config, simulate: bool = False):
+        print(f'+ Run {self.name}')
+        self.function(config)
+
+
 class Manager:
     def __init__(self, config: Config, steps: list, **kwargs):
         self.config = config
